#[unsafe(no_mangle)]pub unsafe extern "C" fn utime(
path: *const c_char,
times: *const utimbuf,
) -> c_int๐Deprecated
See https://pubs.opengroup.org/onlinepubs/9699919799/functions/utime.html.
Sets the access and modification times of the file named by the path
argument.
Upon success, returns 0. Upon failure, returns -1, sets errno to
indicate the error, and the file times shall not be affected.
Deprecated
Marked obsolete in issue 7, removed in issue 8.
Should use utimensat() instead for greater accuracy because utimebuf
uses time_t which represents whole seconds only.